#include <stdio.h>
#include <stdlib.h>
#include <time.h>

int main(int argc, char **argv)
{
	char *date;
	double loadavg[3];
	time_t time_data;

	time(&time_data);
	date=ctime(&time_data);
	
	getloadavg(loadavg, 3);

	printf(" %s %.2f, %.2f, %.2f",
		date, loadavg[0], loadavg[1], loadavg[2]);

	return(0);
}
